## Python package elabjournal

Source Python package [elabjournal](https://pypi.org/project/elabjournal/)

Install with

```bash
pip install elabjournal
```

See [jupyter](https://github.com/matthijsbrouwer/elabjournal-jupyter) notebooks for
a demonstration of functionality.